﻿
using System;
using System.Diagnostics.Tracing;
using Microsoft.Diagnostics.Tracing;


namespace ETW.Common
{
    [EventSource(Name = "CustomEventSource")]
    public class CustomEventSource : EventSource
    {

        public void EfExecutionTime(string query, double executionTime)
        {
            WriteEvent(1, query, executionTime);
        }
        public void Start()
        {
            WriteEvent(2);
        }
        public static CustomEventSource Logger = new CustomEventSource();

        public void Stop()
        {
            WriteEvent(3);
        }

        public static void ReadQueryEvents(string logFile, Action<EfQueryData> callback)
        {
            using (var source = new ETWTraceEventSource(logFile))
            {
                // Set up the callbacks 
                source.Dynamic.All += delegate(TraceEvent data)
                {

                    if (data.EventName == "EfExecutionTime")
                    {
                        var queryData = new EfQueryData
                        {
                            ExecutionTime = (double)data.PayloadByName("executionTime"),
                            Query = (string)data.PayloadByName("query")
                        };
                        callback(queryData);
                    }
                };
                source.Process();//start reading event
            }
        }
    }
}
